@@ -43,6 +43,7 @@ except:
 from . import debug
 from . import event_manager
 from . import messages
+from . import orca
 from . import orca_state
 from . import script_manager
 from . import settings_manager
@@ -66,7 +67,7 @@ class _StringContext:
         - script: The script associated with the accessible object
         """
 
-        self._obj = hash(obj)
+        self._obj = obj
         self._script = script
         self._string = string
         self._start = start
@@ -142,6 +143,8 @@ class _StringContext:
 
         voice = self._script.speechGenerator.voice(string=self._string)
         string = self._script.utilities.adjustForRepeats(self._string)
+
+        orca.emitRegionChanged(self._obj, self._start, self._end, orca.MOUSE_REVIEW)
         self._script.speakMessage(string, voice=voice, interrupt=False)
         self._script.displayBrailleMessage(self._string, -1)
         return True
@@ -289,11 +292,22 @@ class _ItemContext:
         if self._frame and self._frame != prior._frame:
             self._script.presentObject(self._frame, alreadyFocused=True, inMouseReview=True)
 
+        if self._script.utilities.containsOnlyEOCs(self._obj):
+            msg = "MOUSE REVIEW: Not presenting object which contains only EOCs"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return False
+
         if self._obj and self._obj != prior._obj:
             priorObj = prior._obj or self._getContainer()
+            orca.emitRegionChanged(self._obj, mode=orca.MOUSE_REVIEW)
             self._script.presentObject(self._obj, priorObj=priorObj, inMouseReview=True)
+            if self._string.getString() == self._obj.name:
+                return True
             if not self._script.utilities.isEditableTextArea(self._obj):
                 return True
+            if self._obj.getRole() == pyatspi.ROLE_TABLE_CELL \
+               and self._string.getString() == self._script.utilities.displayedText(self._obj):
+                return True
 
         if self._string != prior._string and self._string.present():
             return True
@@ -565,11 +579,6 @@ class MouseReviewer:
                 debug.println(debug.LEVEL_INFO, msg, True)
                 return
 
-        if obj and obj.getRole() in script.utilities.getCellRoles() \
-           and script.utilities.shouldReadFullRow(obj):
-            isRow = lambda x: x and x.getRole() == pyatspi.ROLE_TABLE_ROW
-            obj = pyatspi.findAncestor(obj, isRow) or obj
-
         screen, nowX, nowY = self._pointer.get_position()
         if (pX, pY) != (nowX, nowY):
             msg = "MOUSE REVIEW: Pointer moved again: (%i, %i)" % (nowX, nowY)
