@@ -293,7 +293,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         rowHeader, columnHeader = \
             self._script.utilities.getDynamicHeadersForCell(obj, newOnly)
         if not rowHeader:
-            return []
+            return super()._generateRowHeader(obj, **args)
 
         result = []
         text = self._script.utilities.displayedText(rowHeader)
@@ -303,10 +303,6 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         return result
 
-    def _generateNewRowHeader(self, obj, **args):
-        args['newOnly'] = True
-        return self._generateRowHeader(obj, **args)
-
     def _generateColumnHeader(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the column header for an object
@@ -319,7 +315,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         rowHeader, columnHeader = \
             self._script.utilities.getDynamicHeadersForCell(obj, newOnly)
         if not columnHeader:
-            return []
+            return super()._generateColumnHeader(obj, **args)
 
         result = []
         text = self._script.utilities.displayedText(columnHeader)
@@ -329,10 +325,6 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         return result
 
-    def _generateNewColumnHeader(self, obj, **args):
-        args['newOnly'] = True
-        return self._generateColumnHeader(obj, **args)
-
     def _generateTooLong(self, obj, **args):
         """If there is text in this spread sheet cell, compare the size of
         the text within the table cell with the size of the actual table
