@@ -552,6 +552,8 @@ class Script(default.Script):
 
     def __sayAllProgressCallback(self, context, progressType):
         if progressType == speechserver.SayAllContext.PROGRESS:
+            orca.emitRegionChanged(
+                context.obj, context.currentOffset, context.currentEndOffset, orca.SAY_ALL)
             return
 
         obj = context.obj
@@ -573,6 +575,7 @@ class Script(default.Script):
             self._sayAllContexts = []
             if not self._lastCommandWasStructNav:
                 text.setCaretOffset(offset)
+            orca.emitRegionChanged(obj, offset)
             return
 
         # SayAllContext.COMPLETED doesn't necessarily mean done with SayAll;
@@ -589,6 +592,7 @@ class Script(default.Script):
             if [l for l in links if l.startIndex <= offset <= l.endIndex]:
                 return
 
+        orca.emitRegionChanged(obj, offset, mode=orca.SAY_ALL)
         text.setCaretOffset(offset)
 
     def getTextLineAtCaret(self, obj, offset=None, startOffset=None, endOffset=None):
