@@ -84,7 +84,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if self._script.utilities.isLink(obj) \
            or self._script.utilities.isLandmark(obj) \
            or self._script.utilities.isMath(obj) \
-           or obj.getRole() == pyatspi.ROLE_TOOL_TIP:
+           or obj.getRole() in [pyatspi.ROLE_TOOL_TIP, pyatspi.ROLE_STATUS_BAR]:
             return result
 
         args['stopAtRoles'] = [pyatspi.ROLE_DOCUMENT_FRAME,
@@ -317,6 +317,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
            and not self._script.utilities.isContentSuggestion(obj):
             return []
 
+        if self._script.inSayAll() and obj == args.get('priorObj'):
+            return []
+
         if self._script.utilities.isContentEditableWithEmbeddedObjects(obj):
             lastKey, mods = self._script.utilities.lastKeyAndModifiers()
             if lastKey in ["Home", "End", "Up", "Down", "Left", "Right", "Page_Up", "Page_Down"]:
@@ -330,6 +333,10 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             name = obj.name
             if not self._script.utilities.hasExplicitName(obj):
                 name = name.strip()
+
+            if self._script.utilities.shouldVerbalizeAllPunctuation(obj):
+                name = self._script.utilities.verbalizeAllPunctuation(name)
+
             result = [name]
             result.extend(self.voice(speech_generator.DEFAULT))
             return result
@@ -467,6 +474,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if not self._script.utilities.inDocumentContent(obj):
             return super()._generateRoleName(obj, **args)
 
+        if self._script.inSayAll() and obj == args.get('priorObj'):
+            return []
+
         result = []
         acss = self.voice(speech_generator.SYSTEM)
 
@@ -751,11 +761,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             result = list(filter(lambda x: x, super().generateSpeech(obj, **args)))
 
         self._restoreRole(oldRole, args)
-        msg = "WEB: Speech generation for document object %s complete:" % obj
+        msg = "WEB: Speech generation for document object %s complete." % obj
         debug.println(debug.LEVEL_INFO, msg, True)
-        for element in result:
-            debug.println(debug.LEVEL_ALL, "%s%s" % (' ' * 18, element))
-
         return result
 
     def generateContents(self, contents, **args):
